@@ -34,6 +34,7 @@ pub struct InputElement<'a> {
 }
 
 impl<'a> InputElement<'a> {
+    #[inline]
     fn new(input: &'a str, required_type: InputType) -> Self {
         Self {
             input: if required_type != InputType::typed::<String>() {
@@ -117,60 +118,3 @@ impl<'a> InputFormatParser<'a> {
         return Ok(input_elements);
     }
 }
-
-#[cfg(test)]
-mod test {
-    use super::*;
-
-    #[test]
-    fn test_formatter_simple_generic() {
-        let formatter = InputFormatParser::new("{}").unwrap();
-        assert_eq!(formatter.tokens, vec![InputFormatToken::GenericType])
-    }
-
-    #[test]
-    fn test_formatter_two_generic_with_separator() {
-        let formatter = InputFormatParser::new("{} -> {}").unwrap();
-        assert_eq!(
-            formatter.tokens,
-            vec![
-                InputFormatToken::GenericType,
-                InputFormatToken::Text(" -> "),
-                InputFormatToken::GenericType,
-            ]
-        )
-    }
-
-    #[test]
-    #[should_panic]
-    fn test_wrong_formatter_unescaped_open_bracket() {
-        InputFormatParser::new("{} -{> {}").unwrap();
-    }
-
-    #[test]
-    #[should_panic]
-    fn test_wrong_formatter_unescaped_close_bracket() {
-        InputFormatParser::new("{} -}> {}").unwrap();
-    }
-
-    #[test]
-    fn test_formatter_two_generic_without_separator() {
-        let formatter = InputFormatParser::new("{}{}").unwrap();
-        assert_eq!(
-            formatter.tokens,
-            vec![InputFormatToken::GenericType, InputFormatToken::GenericType,]
-        )
-    }
-
-    #[test]
-    fn test_formatter_number_and_string_without_separator() {
-        let formatter = InputFormatParser::new("{i32}{string}").unwrap();
-        assert_eq!(
-            formatter.tokens,
-            vec![
-                InputFormatToken::typed::<i32>(),
-                InputFormatToken::typed::<String>(),
-            ]
-        )
-    }
-}
