@@ -106,83 +106,3 @@ macro_rules! scanf {
     }};
     ($format:literal, $($var:ident),+ , ) => { $crate::scanf!($format, $($var),*) };
 }
-
-#[cfg(test)]
-mod tests {
-    use super::*;
-
-    #[test]
-    fn strings() {
-        let input = "Hello: world";
-        let mut request: String = String::new();
-        let mut reply: String = String::new();
-        sscanf!(input, "{string}: {string}", request, reply).unwrap();
-        assert_eq!(request, "Hello");
-        assert_eq!(reply, "world");
-    }
-
-    #[test]
-    #[allow(clippy::float_cmp)]
-    fn string_and_float() {
-        let input = "Candy->2.5";
-        let mut product: String = String::new();
-        let mut price: f64 = 0.0;
-        sscanf!(input, "{string}->{f64}", product, price,).unwrap();
-        assert_eq!(product, "Candy");
-        assert_eq!(price, 2.5);
-    }
-
-    #[test]
-    #[allow(clippy::float_cmp)]
-    fn generic() {
-        let input = "5 -> 5.0";
-        let mut request: i32 = 0;
-        let mut reply: f32 = 0.0;
-        sscanf!(input, "{} -> {}", request, reply).unwrap();
-        assert_eq!(request, 5);
-        assert_eq!(reply, 5.0);
-    }
-
-    #[test]
-    fn string_between_brackets_ignored() {
-        let input = "{Hello world}";
-        let mut message: String = String::new();
-        sscanf!(input, "{{{string}}}", message).unwrap();
-        assert_eq!(message, "Hello world");
-    }
-
-    #[test]
-    fn string_generic_between_brackets_ignored() {
-        let input = "{Hello world}";
-        let mut message: String = String::new();
-        sscanf!(input, "{{{}}}", message).unwrap();
-        assert_eq!(message, "Hello world");
-    }
-
-    #[test]
-    #[should_panic]
-    fn wrong_format_string() {
-        let input = "5 -> 5.0 <-";
-        let mut _request: i32 = 0;
-        let mut _reply: f32 = 0.0;
-        sscanf!(input, "{} -}> {} <-", _request, _reply).unwrap();
-    }
-
-    #[test]
-    #[should_panic]
-    fn wrong_format_two_generic_without_separator() {
-        let input = "Hello";
-        let mut _word1: String = String::new();
-        let mut _word2: String = String::new();
-        sscanf!(input, "{}{}", _word1, _word2).unwrap();
-    }
-
-    #[test]
-    #[should_panic]
-    fn wrong_format_placeholder_type() {
-        let input = "5 -> 5.0";
-        let mut _request: i32 = 0;
-        let mut _reply: f32 = 0.0;
-        sscanf!(input, "{u64} -> {f64}", _request, _reply).unwrap();
-    }
-}
